diff -urN strace-4.2.org/acconfig.h strace-4.2/acconfig.h
--- strace-4.2.org/acconfig.h	Tue Sep 19 21:03:50 2000
+++ strace-4.2/acconfig.h	Tue Sep 19 21:04:01 2000
@@ -65,3 +65,9 @@
 
 /* Define if stat64 is available in asm/stat.h.  */
 #undef HAVE_STAT64
+
+/* Define if struct sockaddr_in6 contains sin6_scope_id field. */
+#undef HAVE_SIN6_SCOPE_ID
+
+/* Define if linux struct sockaddr_in6 contains sin6_scope_id fiels. */
+#undef HAVE_SIN6_SCOPE_ID_LINUX
diff -urN strace-4.2.org/aclocal.m4 strace-4.2/aclocal.m4
--- strace-4.2.org/aclocal.m4	Tue Sep 19 21:03:50 2000
+++ strace-4.2/aclocal.m4	Tue Sep 19 21:04:01 2000
@@ -299,3 +299,30 @@
 	AC_DEFINE(HAVE_STAT64)
 fi
 ])
+
+dnl ### A macro to determine whether sin6_scope_id is available.
+AC_DEFUN(AC_SIN6_SCOPE_ID,
+[AC_MSG_CHECKING(for sin6_scope_id in sockaddr_in6)
+AC_CACHE_VAL(ac_cv_have_sin6_scope_id,
+[AC_TRY_COMPILE([#include <netinet/in.h>],
+[ struct sockaddr_in6 s; s.sin6_scope_id = 0; ],
+ac_cv_have_sin6_scope_id=yes,
+ac_cv_have_sin6_scope_id=no)])
+AC_MSG_RESULT($ac_cv_have_sin6_scope_id)
+if test "$ac_cv_have_sin6_scope_id" = "yes" ; then
+       AC_DEFINE(HAVE_SIN6_SCOPE_ID)
+else
+       AC_MSG_CHECKING(for sin6_scope_id in linux sockaddr_in6)
+       AC_CACHE_VAL(ac_cv_have_sin6_scope_id_linux,
+       [AC_TRY_COMPILE([#include <linux/in6.h>],
+       [ struct sockaddr_in6 s; s.sin6_scope_id = 0; ],
+       ac_cv_have_sin6_scope_id_linux=yes,
+       ac_cv_have_sin6_scope_id_linux=no)])
+       AC_MSG_RESULT($ac_cv_have_sin6_scope_id_linux)
+       if test "$ac_cv_have_sin6_scope_id_linux" = "yes" ; then
+               AC_DEFINE(HAVE_SIN6_SCOPE_ID)
+               AC_DEFINE(HAVE_SIN6_SCOPE_ID_LINUX)
+       fi
+fi
+])
+
diff -urN strace-4.2.org/config.h.in strace-4.2/config.h.in
--- strace-4.2.org/config.h.in	Tue Sep 19 21:03:50 2000
+++ strace-4.2/config.h.in	Tue Sep 19 21:04:01 2000
@@ -117,11 +117,20 @@
 /* Define if stat64 is available in asm/stat.h.  */
 #undef HAVE_STAT64
 
+/* Define if struct sockaddr_in6 contains sin6_scope_id field. */
+#undef HAVE_SIN6_SCOPE_ID
+
+/* Define if linux struct sockaddr_in6 contains sin6_scope_id fiels. */
+#undef HAVE_SIN6_SCOPE_ID_LINUX
+
 /* Define if you have the _sys_siglist function.  */
 #undef HAVE__SYS_SIGLIST
 
 /* Define if you have the getdents function.  */
 #undef HAVE_GETDENTS
+
+/* Define if you have the if_indextoname function.  */
+#undef HAVE_IF_INDEXTONAME
 
 /* Define if you have the inet_ntop function.  */
 #undef HAVE_INET_NTOP
diff -urN strace-4.2.org/configure.in strace-4.2/configure.in
--- strace-4.2.org/configure.in	Tue Sep 19 21:03:50 2000
+++ strace-4.2/configure.in	Tue Sep 19 21:04:01 2000
@@ -140,8 +140,9 @@
 AC_HEADER_MAJOR
 AC_SIG_ATOMIC_T
 AC_STAT64
+AC_SIN6_SCOPE_ID
 AC_CHECK_LIB(nsl, main)
-AC_CHECK_FUNCS(sigaction strerror strsignal pread sys_siglist _sys_siglist getdents mctl putpmsg prctl sendmsg inet_ntop)
+AC_CHECK_FUNCS(sigaction strerror strsignal pread sys_siglist _sys_siglist getdents mctl putpmsg prctl sendmsg inet_ntop if_indextoname)
 AC_CHECK_HEADERS(sys/reg.h sys/filio.h sys/acl.h sys/asynch.h sys/door.h sys/stream.h sys/tiuser.h sys/sysconfig.h asm/sigcontext.h ioctls.h sys/ioctl.h sys/ptrace.h termio.h linux/ptrace.h asm/reg.h linux/in6.h sys/uio.h linux/netlink.h linux/if_packet.h)
 AC_DECL_SYS_ERRLIST
 AC_DECL_SYS_SIGLIST
diff -urN strace-4.2.org/net.c strace-4.2/net.c
--- strace-4.2.org/net.c	Tue Sep 19 21:03:50 2000
+++ strace-4.2/net.c	Tue Sep 19 21:04:24 2000
@@ -35,8 +35,14 @@
 #include <sys/stat.h>
 #include <sys/socket.h>
 #include <sys/un.h>
+#if defined(HAVE_SIN6_SCOPE_ID_LINUX)
+#define in6_addr in6_addr_libc
+#define ipv6_mreq ipv6_mreq_libc
+#define sockaddr_in6 sockaddr_in6_libc
+#endif
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <net/if.h>
 #if defined(LINUX)
 #include <asm/types.h>
 #if defined(__GLIBC__) && (__GLIBC__ >= 2) && (__GLIBC__ + __GLIBC_MINOR__ >= 3)
@@ -46,9 +52,25 @@
 #endif
 #endif /* LINUX */
 
-#if defined (__GLIBC__) && ((__GLIBC__ < 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ < 1))
+#if defined (__GLIBC__) && (((__GLIBC__ < 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ < 1)) || defined(HAVE_SIN6_SCOPE_ID_LINUX))
 #if defined(HAVE_LINUX_IN6_H)
+#if defined(HAVE_SIN6_SCOPE_ID_LINUX)
+#undef in6_addr
+#undef ipv6_mreq
+#undef sockaddr_in6
+#define in6_addr in6_addr_kernel
+#define ipv6_mreq ipv6_mreq_kernel
+#define sockaddr_in6 sockaddr_in6_kernel
+#endif
 #include <linux/in6.h>
+#if defined(HAVE_SIN6_SCOPE_ID_LINUX)
+#undef in6_addr
+#undef ipv6_mreq
+#undef sockaddr_in6
+#define in6_addr in6_addr_libc
+#define ipv6_mreq ipv6_mreq_libc
+#define sockaddr_in6 sockaddr_in6_kernel
+#endif
 #endif
 #endif
 
@@ -446,9 +468,30 @@
 #ifdef HAVE_INET_NTOP
 	case AF_INET6:
 		inet_ntop(AF_INET6, &addrbuf.sa6.sin6_addr, string_addr, sizeof(string_addr));
-		tprintf("sin6_port=htons(%u), inet_pton(AF_INET6, \"%s\", &sin6_addr), sin6_flowinfo=htonl(%u)}",
-			ntohs(addrbuf.sa6.sin6_port), string_addr, ntohl(addrbuf.sa6.sin6_flowinfo));
-		break;	
+		tprintf("sin6_port=htons(%u), inet_pton(AF_INET6, \"%s\", &sin6_addr), sin6_flowinfo=%u",
+				ntohs(addrbuf.sa6.sin6_port), string_addr,
+				addrbuf.sa6.sin6_flowinfo);
+#ifdef HAVE_SIN6_SCOPE_ID
+		{
+#if defined(HAVE_IF_INDEXTONAME) && defined(IN6_IS_ADDR_LINKLOCAL) && defined(IN6_IS_ADDR_MC_LINKLOCAL)
+		    int numericscope = 0;
+		    if (IN6_IS_ADDR_LINKLOCAL (&addrbuf.sa6.sin6_addr)
+			    || IN6_IS_ADDR_MC_LINKLOCAL (&addrbuf.sa6.sin6_addr)) {
+			char scopebuf[IFNAMSIZ + 1];
+			
+			if (if_indextoname (addrbuf.sa6.sin6_scope_id, scopebuf) == NULL)
+			    numericscope++;
+			else
+			    tprintf(", sin6_scope_id=if_nametoindex(\"%s\")", scopebuf);
+		    } else
+			numericscope++;
+		    
+		    if (numericscope)
+#endif
+			tprintf(", sin6_scope_id=%u", addrbuf.sa6.sin6_scope_id);
+		}
+#endif
+		    break;
 #endif
 #if defined(AF_IPX) && defined(linux)
 	case AF_IPX:
